@@ -6,6 +6,7 @@ from sanic_ext.extensions.base import Extension
 from sanic_ext.extensions.http.cors import cors
 from sanic_ext.extensions.openapi import openapi
 from sanic_ext.extensions.templating.render import render
+from sanic_ext.extras.request import CountedRequest
 from sanic_ext.extras.serializer.decorator import serializer
 from sanic_ext.extras.validation.decorator import validate
 
@@ -13,6 +14,7 @@ __version__ = version("sanic-ext")
 
 __all__ = [
     "Config",
+    "CountedRequest",
     "Extend",
     "Extension",
     "cors",
