@@ -3,6 +3,7 @@ from __future__ import annotations
 import asyncio
 from dataclasses import dataclass
 from itertools import count
+from typing import Optional
 
 import pytest
 from sanic import Request, json, text
@@ -34,7 +35,7 @@ class Person:
     age: int
 
     @classmethod
-    async def create(cls, request, person_id: int) -> Person:
+    async def create(cls, person_id: int) -> Person:
         return cls(person_id=PersonID(person_id), name="noname", age=111)
 
 
@@ -97,6 +98,35 @@ class E:
         return cls(c, d)
 
 
+class Alpha:
+    ...
+
+
+class Beta:
+    def __init__(self, alpha: Alpha) -> None:
+        self.alpha = alpha
+
+
+class Gamma:
+    def __init__(self, beta: Beta, request: Optional[Request] = None) -> None:
+        self.beta = beta
+        self.request = request
+
+
+class Delta:
+    def __init__(self, gamma: Gamma, request: Request) -> None:
+        self.gamma = gamma
+        self.request = request
+
+
+def make_gamma_with_request(beta: Beta, request: Request):
+    return Gamma(beta, request)
+
+
+def make_gamma_without_request(beta: Beta):
+    return Gamma(beta)
+
+
 def test_injection_not_allowed_when_ext_disabled(bare_app):
     ext = Extend(bare_app, built_in_extensions=False)
 
@@ -280,3 +310,88 @@ def test_injection_of_awaitable_variable_in_call(app):
     assert response.body == b"george"
     assert isinstance(request.ctx.name, AsyncName)
     assert request.ctx.name.name == "george"
+
+
+def test_injection_class_constructors(app):
+    app.ext.add_dependency(Alpha)
+    app.ext.add_dependency(Beta)
+
+    @app.get("/")
+    def handler(request: Request, beta: Beta):
+        return json({"is_beta": isinstance(beta, Beta)})
+
+    _, response = app.test_client.get("/")
+    assert response.json == {"is_beta": True}
+
+
+def test_injection_class_constructors_with_optional_request(app):
+    app.ext.add_dependency(Alpha)
+    app.ext.add_dependency(Beta)
+    app.ext.add_dependency(Gamma)
+
+    @app.get("/")
+    def handler(request: Request, gamma: Gamma):
+        return json(
+            {
+                "is_gamma": isinstance(gamma, Gamma),
+                "has_request": bool(gamma.request),
+            }
+        )
+
+    _, response = app.test_client.get("/")
+    assert response.json == {"is_gamma": True, "has_request": True}
+
+
+def test_injection_class_constructors_with_request(app):
+    app.ext.add_dependency(Alpha)
+    app.ext.add_dependency(Beta)
+    app.ext.add_dependency(Gamma)
+    app.ext.add_dependency(Delta)
+
+    @app.get("/")
+    def handler(request: Request, delta: Delta):
+        return json(
+            {
+                "is_delta": isinstance(delta, Delta),
+                "has_request": bool(delta.request),
+            }
+        )
+
+    _, response = app.test_client.get("/")
+    assert response.json == {"is_delta": True, "has_request": True}
+
+
+def test_injection_class_constructors_with_func_and_request(app):
+    app.ext.add_dependency(Alpha)
+    app.ext.add_dependency(Beta)
+    app.ext.add_dependency(Gamma, make_gamma_with_request)
+
+    @app.get("/")
+    def handler(request: Request, gamma: Gamma):
+        return json(
+            {
+                "is_gamma": isinstance(gamma, Gamma),
+                "has_request": bool(gamma.request),
+            }
+        )
+
+    _, response = app.test_client.get("/")
+    assert response.json == {"is_gamma": True, "has_request": True}
+
+
+def test_injection_class_constructors_with_func_and_no_request(app):
+    app.ext.add_dependency(Alpha)
+    app.ext.add_dependency(Beta)
+    app.ext.add_dependency(Gamma, make_gamma_without_request)
+
+    @app.get("/")
+    def handler(request: Request, gamma: Gamma):
+        return json(
+            {
+                "is_gamma": isinstance(gamma, Gamma),
+                "has_request": bool(gamma.request),
+            }
+        )
+
+    _, response = app.test_client.get("/")
+    assert response.json == {"is_gamma": True, "has_request": False}
